# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.utils.translation import ugettext as _

from .models import AddressScope


class AddressScopeAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('name', 'slug', 'is_invoice_address', 'is_shipping_address')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'name',
        'is_invoice_address', 'is_shipping_address', 'ordering',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {"slug": ("name",)}


class AddressAdmin(admin.ModelAdmin):
    fieldset = (
        (_('general information'), {
           'fields': (
               'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale',
               'floor', 'zip_code', 'locality', 'province', 'country', 'post_office',
           )
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale', 'floor',
        'zip_code', 'locality', 'province', 'country', 'post_office',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class AddressCoordinatesAdmin(admin.ModelAdmin):
    """
    Use this model admin to include necessary js to display google map
    for the stored coordinates.  If your inherited admin overwrites
    any attributes be careful to include these js in Media class and
    'google_map' as readonly field.
    """
    fieldsets = (
        (_('coordinates'), {
            'fields': ('lat', 'lng', 'google_map'),
        }),
    )
    list_display = ('lat', 'lng',)
    readonly_fields = ('google_map',)

    class Media:
        js = (
            "https://maps.googleapis.com/maps/api/js?key={}".format(
                settings.ADDRESS_GOOGLE_GEOCODING_KEY
            ),
            "address/js/address_coordinates.js",
        )


admin.site.register(AddressScope, AddressScopeAdmin)
